# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/eric/testing/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/eric/testing/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Eric\\Testing\\": "packages/eric/testing/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Eric\Testing\Providers\TestingServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Testing'  => Eric\Testing\Facades\Testing::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Eric\\TestingTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Eric\Testing\Providers\TestingServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Eric\Testing\Providers\TestingServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Eric\Testing\Providers\TestingServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/testing/{modulename}

**User**

    http://path-to-route-folder/user/testing/{modulename}

**Public**

    http://path-to-route-folder/testings


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/testing/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/testing/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/testing/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/testing/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/testing/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/testing/{modulename}/{slug}
    METHOD: GET